function [ A, l, r ] = NonnegativeRoundingRankOne(B)
%NONNEGATIVEROUNDINGRANKONE Checks nestedness and returns NNRR factorization
%
%   A = NonnegativeRoundingRankOne(B) returns non-negative A s.t. 
%       Round(A) = B if B is nested, and all-zeros A otherwise.
%   [A, L, R] = NonnegativeRoundingRankOne(B) returns also factors L and R
%       s.t. A = L*R'.
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

[d,C,permutationBtoCrows,permutationCtoBrows,permutationBtoCcols,permutationCtoBcols] = IsNested(B);
% C is the directly nested version of B

% stop if B is not nested
if ~d
	A = 0;
	return;
end

m = size(B,1);
n = size(B,2);

p = C * ones(n,1);

l = 2.^(p - 1);
r = 2.^(-(1:n));

l = l(permutationCtoBrows);
r = r(permutationCtoBcols);

A = l * r;
%A = A(permutationCtoBrows,permutationCtoBcols); % permutate A to be in line with B

