function [ lb ] = RRLowerBound(B)
%RRLowerBound Computes a lower bound on the rounding rank of a matrix.
%   lb = RRLowerBound(B) returns the lower bound as explained
%       in Proposition 4 in the main paper. This lower bound originates 
%       from Forster and Simon, TCS 2006.
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016
m = size(B,1);
n = size(B,2);

B(B == 0) = -1;
S = svd(B);
S = S.^2;
entries = m*n;

csum = cumsum(S);


for d = 1:min(m,n)
    %summation = sum(S(1:d));
    summation = csum(d);
    
    if (d+1)*summation >= entries
        lb = d;
        return
    end
end

lb = min(m, n); % If we somehow went through the above for-loop,
                % we return this (possible if the matrix has full
                % rank and we have some numerical issues. 

end

