function [ LL ] = loglikelihood( X, Z )
%LOGLIKELIHOOD Computes the loglikelihood of X given Z
%   LL = LOGLIKELIHOOD(X, Z) returns the loglikelihood of X given Z under
%   the logistic model. 
%
%   See also: LPCA_FIT
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

p = inputParser;
addRequired(p, 'X', @(x) validateattributes(x, {'numeric'}, {'2d', 'binary'}, mfilename, 'X', 1));
addRequired(p, 'Z', @(x) validateattributes(x, {'numeric'}, {'2d'}, mfilename, 'Z', 2));
parse(p, X, Z);

if any(size(X) ~= size(Z)) error('The two matrices must be of the same size'); end

i0 = X == 0;  % To prevent constant * NaN errors we separate
i1 = X == 1;  %% 1's from 0's for likelihood calculations.
LL = -sum(sum(log(1+exp(Z(i0))))) - sum(sum(log(1+exp(Z(i1)))));
end

