% MAKE_SYNTH_DATA creates synthetic data sets
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

%% Parameters
% Small data is (60:220)-by-100 with rank 5:30
N = 60:40:220;
defN = 100;
m = 100;
K = 5:5:30;
defK = 10;
% Big data is 500-by-300 with rank 60
bigN = 500;
bigM = 300;
bigK = 60;

Noise = 0.05:0.05:0.5;
defNoise = 0;

tau = 0.5; % Rounding threshold

% Density is 0.1:0.7; in reality, the expected value in the matrix to be
% rounded
Density = 0.1:0.1:0.7;
defDensity = 0.5;


Iterations = 10;

datadir='../data/synth';

if false
%% Different N - no noise
k = defK;
noise = defNoise;
dens = defDensity;

for nIter=1:length(N),
    n = N(nIter);
    for iter=1:Iterations,
        p = sqrt(dens/k);
        L = randn(n, k)+p;
        R = randn(k, m)+p;
        B = Round(L*R, tau);
        save(sprintf('%s/norm_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'B', 'L', 'R');
        L = rand(n, k) + p - 1/2;
        R = rand(k, m) + p - 1/2;
        B = Round(L*R, tau);
        save(sprintf('%s/unif_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'B', 'L', 'R');
    end
end

%% Different K - no noise
n = defN;
noise = defNoise;
dens = defDensity;

for kIter=1:length(K),
    k = K(kIter);
    for iter=1:Iterations,
        p = sqrt(dens/k);
        L = randn(n, k)+p;
        R = randn(k, m)+p;
        B = Round(L*R, tau);
        save(sprintf('%s/norm_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'B', 'L', 'R');
        L = rand(n, k) + p - 1/2;
        R = rand(k, m) + p - 1/2;
        B = Round(L*R, tau);
        save(sprintf('%s/unif_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'B', 'L', 'R');
    end
end

%% Different density - no noise
k = defK;
n = defN;
noise = defNoise;

for dIter=1:length(Density),
    dens = Density(dIter);
    for iter=1:Iterations,
        p = sqrt(dens/k);
        L = randn(n, k)+p;
        R = randn(k, m)+p;
        B = Round(L*R, tau);
        save(sprintf('%s/norm_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'B', 'L', 'R');
        L = rand(n, k) + p - 1/2;
        R = rand(k, m) + p - 1/2;
        B = Round(L*R, tau);
        save(sprintf('%s/unif_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'B', 'L', 'R');
    end
end

end

%% Vary noise
n = defN;
k = defK;
dens = defDensity;

for noiseIter = 1:length(Noise),
    noise = Noise(noiseIter);
    for iter=1:Iterations,
        p = sqrt(dens/k);
        L = randn(n, k)+p;
        R = randn(k, m)+p;
        Borig = Round(L*R, tau);
        No = rand(n, m) <= noise*nnz(Borig)/(n*m);
        B = double(xor(Borig, No));
        save(sprintf('%s/norm_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'Borig', 'B', 'L', 'R');

        L = rand(n, k) + p - 1/2;
        R = rand(k, m) + p - 1/2;
        Borig = Round(L*R, tau);
        No = rand(n, m) <= noise*nnz(Borig)/(n*m);
        B = double(xor(Borig, No));
        save(sprintf('%s/unif_%03i_%03i_%03i_%.2f_%.2f_%02i.mat', ...
            datadir, n, m, k, dens, noise, iter), 'Borig', 'B', 'L', 'R');
    end
end 
