%PLOT_SYNTH_BIG_RANK plots the results of synthetic big matrix rank
%experiments.
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

res_dir='../results/synth/';

fontsize=12;
lenged_fontsize=12;
markersize=8;
linewidth=1.2;
colours = struct('proje', [1 0 0], 'nuclear', [0 1 0], 'SVD', [0 0 1], ...
    'shay', [sqrt(0.5), sqrt(0.5), 0], 'lpca', [sqrt(0.5), 0, sqrt(0.5)]);
markers = struct('proje', 's', 'nuclear', 'd', 'SVD', '+', ...
    'shay', 'o', 'lpca', 'x');
names = struct(...
        'proje',     'ProjLP',  ...
        'SVD',       'R-SVD',   ...
        'nuclear',   'Nuclear', ...
        'lpca',      'L-PCA',   ...
        'shay',      'Shay''s', ...
        'truncSVD',  'T-SVD'        );

h=[];
plotnames={};

%% N
data=load([res_dir 'big_vary_n_all.mat']);
projections = {'proje', 'SVD', 'lpca'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_big_vary_n_%s_%s', distro{:}, prop{:});
        hold on;
        for proj = projections
            errorbar(data.N, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.N);
        axis tight
        l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
        xlabel('Rows in matrix');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                title(['Estimated rank vs. rows with distribution ' distro{:}]);
            case 'time'
                ylabel('Time (sec)');
                title(['Time vs. rows with distribution ' distro{:}]);
        end
    end
end

%% K
data=load([res_dir 'big_vary_k_all_no_lpca.mat']);
projections = {'proje', 'SVD'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_big_vary_k_%s_%s', distro{:}, prop{:});
        e=[];
        hold on;
        for proj = projections
            e(end+1) = errorbar(data.K, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        if prop{:} == 'rank'
            plot(data.K, data.K, 'Color', [0.5 0.5 0.5], 'LineStyle', '--', 'LineWidth', linewidth);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.K);
        axis tight
        l = legend(e, algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
        xlabel('Planted rounding rank');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                title(['Estimated rank vs. planted rank ' distro{:}]);
            case 'time'
                ylabel('Time (sec)');
                title(['Time vs. planted rank ' distro{:}]);
        end
    end
end

%% Density
data=load([res_dir 'big_vary_dens_all_no_lpca.mat']);
projections = {'proje', 'SVD'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_big_vary_dens_%s_%s', distro{:}, prop{:});
        e=[];
        hold on;
        for proj = projections
            e(end+1) = errorbar(data.Density, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.Density);
        axis tight
        l = legend(e, algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
        xlabel('Data density');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                title(['Estimated rank vs. density ' distro{:}]);
            case 'time'
                ylabel('Time (sec)');
                title(['Time vs. density ' distro{:}]);
        end
    end
end

%% Noise
data=load([res_dir 'big_vary_noise_all_no_lpca.mat']);
projections = {'proje', 'SVD'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_big_vary_noise_%s_%s', distro{:}, prop{:});
        e=[];
        hold on;
        for proj = projections
            e(end+1) = errorbar(data.Noise, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.Noise);
        axis tight
        l = legend(e, algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
        xlabel('Noise level');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                title(['Estimated rank vs. noise level ' distro{:}]);
            case 'time'
                ylabel('Time (sec)');
                title(['Time vs. noise level ' distro{:}]);
        end
    end
end

%% Projection and N
data=load([res_dir 'vary_projections_and_n_all.mat']);
algo_names = {'Sparse', 'Normal', 'Binary', 'Uniform'};
distros = {'unif'};
properties = {'rank', 'time'};

linestyles = struct('sparse', '-', 'normal', '-.', 'binary', '--', 'uniform', ':');

for prop=properties
    h(end+1)=figure;
    plotnames{end+1} = sprintf('rank_big_vary_projection_and_n_%s', prop{:});
    hold on;
    for proj = data.projections
        errorbar(data.N, mean(data.proje.(proj{:}).(prop{:})), ...
            std(data.proje.(proj{:}).(prop{:})), ...
            'Color', colours.proje, 'Marker', markers.proje, ...
            'LineStyle', linestyles.(proj{:}), ...
            'LineWidth', linewidth, 'MarkerSize', markersize);
    end
    set(gca, 'FontSize', fontsize);
    set(gca, 'XTick', data.N);
    axis tight
    l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
    xlabel('Rows in matrix');
    switch prop{:}
        case 'rank'
            ylabel('Estimated rank');
            title(['Estimated rank vs. rows in matrix with different projections']);
        case 'time'
            ylabel('Time (sec)');
            title(['Time vs. rows in matrix with different projections']);
    end
end
