%PLOT_SYNTH_NESTED plots the results of the synthetic nestedness
%experiments.
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

res_dir='../results/synth/';

fontsize=20;
lenged_fontsize=20;
markersize=16;
linewidth=1.1;
colours = struct(...
    'proje',    [1 0 0],                   ...
    'nuclear',  [0 1 0],                   ...
    'SVD',      [0 0 1],                   ...
    'shay',     [sqrt(0.5), sqrt(0.5), 0], ...
    'lpca',     [sqrt(0.5), 0, sqrt(0.5)], ...
    'asso',     [0 0.2 0.3],               ...
    'sgd',      [0 1 1],                   ...
    'truncSVD', [0.1 0 0.5],               ...
    'mt',       [0 1 0],                   ...
    'greedy',   [1 0 0],                   ...
    'mt_greedy',[0 1 1]                        );

markers = struct(...
    'proje',     's', ...
    'nuclear',   'd', ...
    'SVD',       '+', ...
    'shay',      'o', ...
    'lpca',      'x', ...
    'asso',      '>', ...
    'truncSVD',  '*', ...
    'sgd',       '<', ...      
    'mt',        '+', ...
    'greedy',    'x', ...
    'mt_greedy', 'o'      );

names = struct(...
        'proje',     'ProjLP',  ...
        'SVD',       'R-SVD',   ...
        'nuclear',   'Nuclear', ...
        'lpca',      'L-PCA',   ...
        'shay',      'Shay''s', ...
        'truncSVD',  'T-SVD',   ...
        'asso',      'Asso',    ...
        'sgd',       'SGD',     ...
        'mt',        'MT',      ...
        'greedy',    'NNRR1',   ...
        'mt_greedy', 'MT+NNRR1'    );

linestyles = struct(...
        'proje',     '-',  ...
        'SVD',       '-',  ...
        'nuclear',   '-',  ...
        'lpca',      '-',  ...
        'shay',      '-',  ...
        'truncSVD',  '-.', ...
        'asso',      '-.', ...
        'sgd',       '-',  ...
        'mt',        '-',  ...
        'greedy',    '-',  ...
        'mt_greedy', '-'      );
    


h=[];
plotnames={};




%% Density
data=load([res_dir 'nested_vary_dens.mat']);
projections = {'greedy', 'mt', 'mt_greedy', 'SVD'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
properties = {'err', 'errOrig', 'time'};
X = data.Density;

for prop=properties
    h(end+1)=figure;
    plotnames{end+1} = sprintf('nested_dens_%s', prop{:});
    hold on;
    for proj = projections
        switch prop{:}
            case 'err'
                normalizer = data.(proj{:}).nnz;
            case 'errOrig'
                normalizer = data.(proj{:}).nnzOrig;
            otherwise
                normalizer = ones(size(data.(proj{:}).(prop{:})));
        end
        errorbar(X, mean(data.(proj{:}).(prop{:})./normalizer), ...
            std(data.(proj{:}).(prop{:})./normalizer), ...
            'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
            'LineStyle', linestyles.(proj{:}), ...
            'LineWidth', linewidth, 'MarkerSize', markersize);
    end
    set(gca, 'FontSize', fontsize);
    set(gca, 'XTick', X);
    axis tight

    xlabel('Density');
    switch prop{:}
        case 'err'
            ylabel('Relative reconstruction error');
            %title('Nested Reconstruction error vs. density');
            %l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
        case 'errOrig'
            ylabel('Relative reconstruction error');
            %title('Nested Reconstruction error in the original data vs. density');
        case 'time'
            ylabel('Time (sec)');
            %title('Nested Time vs. density');
    end
end

%% Noise
data=load([res_dir 'nested_vary_noise.mat']);
projections = {'greedy', 'mt', 'mt_greedy', 'SVD'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
properties = {'err', 'errOrig', 'time'};
X = data.Noise;

for prop=properties
    h(end+1)=figure;
    plotnames{end+1} = sprintf('nested_noise_%s', prop{:});
    hold on;
    for proj = projections
        switch prop{:}
            case 'err'
                normalizer = data.(proj{:}).nnz;
            case 'errOrig'
                normalizer = data.(proj{:}).nnzOrig;
            otherwise
                normalizer = ones(size(data.(proj{:}).(prop{:})));
        end
        errorbar(X, mean(data.(proj{:}).(prop{:})./normalizer), ...
            std(data.(proj{:}).(prop{:})./normalizer), ...
            'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
            'LineStyle', linestyles.(proj{:}), ...
            'LineWidth', linewidth, 'MarkerSize', markersize);
    end
    set(gca, 'FontSize', fontsize);
    set(gca, 'XTick', X);
    axis tight
    %l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
    xlabel('Noise level');
    switch prop{:}
        case 'err'
            ylabel('Relative reconstruction error');
            %title('Nested Reconstruction error vs. noise level');
        case 'errOrig'
            ylabel('Relative reconstruction error');
            %title('Nested Reconstruction error in the original data vs. noise level');
        case 'time'
            ylabel('Time (sec)');
            %title('Nested Time vs. noise level');
    end
end

