%PLOT_SYNTH_SMALL_ERR plots the results of the small synthetic error experiments.
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

res_dir='../results/synth/';

fontsize=16;
lenged_fontsize=16;
markersize=10;
linewidth=1.2;
colours = struct(...
    'proje',    [1 0 0],                   ...
    'nuclear',  [0 1 0],                   ...
    'SVD',      [0 0 1],                   ...
    'shay',     [sqrt(0.5), sqrt(0.5), 0], ...
    'lpca',     [sqrt(0.5), 0, sqrt(0.5)], ...
    'asso',     [0 0.2 0.3],               ...
    'sgd',      [0 1 1],                   ...
    'truncSVD', [0.1 0 0.5]                    );

markers = struct(...
    'proje',    's', ...
    'nuclear',  'd', ...
    'SVD',      '+', ...
    'shay',     'o', ...
    'lpca',     'x', ...
    'asso',     '>', ...
    'truncSVD', '*', ...
    'sgd',      '<'      );

names = struct(...
        'proje',     'ProjLP',  ...
        'SVD',       'R-SVD',   ...
        'nuclear',   'Nuclear', ...
        'lpca',      'L-PCA',   ...
        'shay',      'Shay''s', ...
        'truncSVD',  'T-SVD',   ...
        'asso',      'Asso',    ...
        'sgd',       'SGD'          );

linestyles = struct(...
        'proje',     '-',  ...
        'SVD',       '-',  ...
        'nuclear',   '-',  ...
        'lpca',      '-',  ...
        'shay',      '-',  ...
        'truncSVD',  '-.', ...
        'asso',      '-.', ...
        'sgd',       '-'       );
    


h=[];
plotnames={};

%% N
for kplus = [0 10]
    data=load([res_dir 'err_small_vary_n_kplus_' int2str(kplus) '.mat']);
    projections = {'proje', 'lpca', 'sgd', 'SVD', 'truncSVD', 'asso'};
    algo_names = cell(length(projections), 1);
    for p = 1:length(projections)
        algo_names{p} = names.(projections{p});
    end
    distros = {'norm', 'unif'};
    properties = {'err', 'errOrig', 'time'};
    
    for prop=properties
        for distro=distros
            h(end+1)=figure;
            plotnames{end+1} = sprintf('err_small_vary_n_%s_%s_kplus_%i', distro{:}, prop{:}, kplus);
            hold on;
            for proj = projections
                switch prop{:}
                    case 'err'
                        normalizer = data.(proj{:}).(distro{:}).nnz;
                    case 'errOrig'
                        normalizer = data.(proj{:}).(distro{:}).nnzOrig;
                    otherwise
                        normalizer = ones(size(data.(proj{:}).(distro{:}).(prop{:})));
                end
                errorbar(data.N, mean(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    std(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                    'LineStyle', linestyles.(proj{:}), ...
                    'LineWidth', linewidth, 'MarkerSize', markersize);
            end
            set(gca, 'FontSize', fontsize);
            set(gca, 'XTick', data.N);
            axis tight
            l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
            xlabel('Rows in matrix');
            switch prop{:}
                case 'err'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error vs. rows with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'errOrig'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error in the original data vs. rows with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'time'
                    ylabel('Time (sec)');
                    title(['Time vs. rows with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
            end
        end
    end
end

%% K
for kplus = [0 10]
    data=load([res_dir 'err_small_vary_k_kplus_' int2str(kplus) '.mat']);
    projections = {'proje', 'lpca', 'sgd', 'SVD', 'truncSVD', 'asso'};
    algo_names = cell(length(projections), 1);
    for p = 1:length(projections)
        algo_names{p} = names.(projections{p});
    end
    distros = {'norm', 'unif'};
    properties = {'err', 'errOrig', 'time'};
    X = data.K;
    
    for prop=properties
        for distro=distros
            h(end+1)=figure;
            plotnames{end+1} = sprintf('err_small_vary_k_%s_%s_kplus_%i', distro{:}, prop{:}, kplus);
            hold on;
            for proj = projections
                switch prop{:}
                    case 'err'
                        normalizer = data.(proj{:}).(distro{:}).nnz;
                    case 'errOrig'
                        normalizer = data.(proj{:}).(distro{:}).nnzOrig;
                    otherwise
                        normalizer = ones(size(data.(proj{:}).(distro{:}).(prop{:})));
                end
                errorbar(X, mean(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    std(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                    'LineStyle', linestyles.(proj{:}), ...
                    'LineWidth', linewidth, 'MarkerSize', markersize);
            end
            set(gca, 'FontSize', fontsize);
            set(gca, 'XTick', X);
            axis tight
            l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
            xlabel('Planted rank');
            switch prop{:}
                case 'err'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error vs. planted rank with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'errOrig'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error in the original data vs. planted rank with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'time'
                    ylabel('Time (sec)');
                    title(['Time vs. planted rank with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
            end
        end
    end
end


%% Density
for kplus = [0 10]
    data=load([res_dir 'err_small_vary_dens_kplus_' int2str(kplus) '.mat']);
    projections = {'proje', 'lpca', 'SVD', 'truncSVD', 'asso'}; % 'sgd', 
    algo_names = cell(length(projections), 1);
    for p = 1:length(projections)
        algo_names{p} = names.(projections{p});
    end
    distros = {'norm', 'unif'};
    properties = {'err', 'errOrig', 'time'};
    X = data.Density;
    
    for prop=properties
        for distro=distros
            h(end+1)=figure;
            plotnames{end+1} = sprintf('err_small_vary_dens_%s_%s_kplus_%i', distro{:}, prop{:}, kplus);
            hold on;
            for proj = projections
                switch prop{:}
                    case 'err'
                        normalizer = data.(proj{:}).(distro{:}).nnz;
                    case 'errOrig'
                        normalizer = data.(proj{:}).(distro{:}).nnzOrig;
                    otherwise
                        normalizer = ones(size(data.(proj{:}).(distro{:}).(prop{:})));
                end
                errorbar(X, mean(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    std(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                    'LineStyle', linestyles.(proj{:}), ...
                    'LineWidth', linewidth, 'MarkerSize', markersize);
            end
            set(gca, 'FontSize', fontsize);
            set(gca, 'XTick', X);
            axis tight
            l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
            xlabel('Density');
            switch prop{:}
                case 'err'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error vs. density with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'errOrig'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error in the original data vs. density with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'time'
                    ylabel('Time (sec)');
                    title(['Time vs. density with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
            end
        end
    end
end


%% Noise
for kplus = [0 10]
    data=load([res_dir 'err_small_vary_noise_kplus_' int2str(kplus) '.mat']);
    projections = {'proje', 'lpca', 'SVD', 'truncSVD', 'asso'}; % 'sgd', 
    algo_names = cell(length(projections), 1);
    for p = 1:length(projections)
        algo_names{p} = names.(projections{p});
    end
    distros = {'norm', 'unif'};
    properties = {'err', 'errOrig', 'time'};
    X = data.Noise;
    
    for prop=properties
        for distro=distros
            h(end+1)=figure;
            plotnames{end+1} = sprintf('err_small_vary_noise_%s_%s_kplus_%i', distro{:}, prop{:}, kplus);
            hold on;
            for proj = projections
                switch prop{:}
                    case 'err'
                        normalizer = data.(proj{:}).(distro{:}).nnz;
                    case 'errOrig'
                        normalizer = data.(proj{:}).(distro{:}).nnzOrig;
                    otherwise
                        normalizer = ones(size(data.(proj{:}).(distro{:}).(prop{:})));
                end
                errorbar(X, mean(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    std(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                    'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                    'LineStyle', linestyles.(proj{:}), ...
                    'LineWidth', linewidth, 'MarkerSize', markersize);
            end
            set(gca, 'FontSize', fontsize);
            set(gca, 'XTick', X);
            axis tight
            l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
            xlabel('Noise level');
            switch prop{:}
                case 'err'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error vs. noise level with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'errOrig'
                    ylabel('Relative reconstruction error');
                    title(['Reconstruction error in the original data vs. noise level with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
                case 'time'
                    ylabel('Time (sec)');
                    title(['Time vs. noise level with distribution ' distro{:} ' and rank + ' int2str(kplus)]);
            end
        end
    end
end

%% Rank
data=load([res_dir 'err_small_vary_rank.mat']);
projections = {'proje', 'lpca', 'SVD', 'truncSVD', 'asso'}; % 'sgd',
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'err', 'errOrig', 'time'};
X = data.Rank;

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('err_small_vary_rank_%s_%s', distro{:}, prop{:});
        hold on;
        for proj = projections
            switch prop{:}
                case 'err'
                    normalizer = data.(proj{:}).(distro{:}).nnz;
                case 'errOrig'
                    normalizer = data.(proj{:}).(distro{:}).nnzOrig;
                otherwise
                    normalizer = ones(size(data.(proj{:}).(distro{:}).(prop{:})));
            end
            errorbar(X, mean(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                std(data.(proj{:}).(distro{:}).(prop{:})./normalizer), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineStyle', linestyles.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', X);
        axis tight
        l = legend(algo_names, 'Location', 'best', 'FontSize', lenged_fontsize);
        xlabel('Decomposition rank');
        switch prop{:}
            case 'err'
                ylabel('Relative reconstruction error');
                title(['Reconstruction error vs. decomposition rank with distribution ' distro{:}]);
            case 'errOrig'
                ylabel('Relative reconstruction error');
                title(['Reconstruction error in the original data vs. decomposition rank with distribution ' distro{:}]);
            case 'time'
                ylabel('Time (sec)');
                title(['Time vs. decomposition rank with distribution ' distro{:}]);
        end
    end
end
