%PLOT_SYNTH_SMALL_RANK Plots the results of the small synthetic rank experiments.
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

res_dir='../results/synth/';

fontsize=20;
legend_fontsize=20;
%legend_markersize=4;
markersize=16;
linewidth=1.1;
%legend_linewidth=0.5;
colours = struct('proje',   [1         0         0        ], ...
                 'nuclear', [0         1         0        ], ...
                 'SVD',     [0         0         1        ], ...
                 'shay',    [sqrt(0.5) sqrt(0.5) 0        ], ...
                 'lpca',    [sqrt(0.5) 0         sqrt(0.5)], ...
                 'LB',      [0         sqrt(0.5) sqrt(0.5)], ...
                 'planted', [0.5       0.5       0.5      ]     );
markers = struct('proje',   's', ...
                 'nuclear', 'd', ...
                 'SVD',     '+', ...
                 'shay',    'o', ...
                 'lpca',    'x', ...
                 'LB',      'v', ...
                 'planted', 'none'      );
             
linestyle = struct('proje',   '-', ...
                   'nuclear', '-', ...
                   'SVD',     '-', ...
                   'shay',    '-', ...
                   'lpca',    '-', ...
                   'LB',      '-', ...
                   'planted', '--'      );

names = struct(...
        'proje',     'ProjLP',      ...
        'SVD',       'R-SVD',       ...
        'nuclear',   'Nuclear',     ...
        'lpca',      'L-PCA',       ...
        'shay',      'Permutation', ...
        'truncSVD',  'T-SVD',       ...
        'LB',        'Spectral LB', ...
        'planted',   'Planted rank'    );


h=[];
plotnames={};

defaultK = 10;

%% N
data=load([res_dir 'vary_n_all.mat']);
projections = {'proje', 'nuclear', 'SVD', 'lpca', 'LB'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_small_vary_n_%s_%s', distro{:}, prop{:});
        hold on;
        for proj = projections
            errorbar(data.N, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        if prop{:} == 'rank'
            plot([data.N(1) data.N(end)], [defaultK defaultK], 'Color', [0.5 0.5 0.5], 'LineStyle', '--', 'LineWidth', linewidth);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.N);
        axis tight
        
        xlabel('Rows in matrix');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                %title(['Estimated rank vs. rows with distribution ' distro{:}]);
            case 'time'
                %l = legend(algo_names, 'Location', 'best', 'FontSize', legend_fontsize);
                ylabel('Time (sec)');
                %title(['Time vs. rows with distribution ' distro{:}]);
        end
    end
end

%% K
data=load([res_dir 'vary_k_all.mat']);
projections = {'proje', 'nuclear', 'SVD', 'lpca', 'shay', 'LB'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_small_vary_k_%s_%s', distro{:}, prop{:});
        e=[];
        hold on;
        for proj = projections
            e(end+1) = errorbar(data.K, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        if prop{:} == 'rank'
            plot(data.K, data.K, 'Color', [0.5 0.5 0.5], 'LineStyle', '--', 'LineWidth', linewidth);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.K);
        axis tight
        
        xlabel('Planted rounding rank');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                %title(['Estimated rank vs. planted rank ' distro{:}]);
            case 'time'
                %l = legend(e, algo_names, 'Location', 'best', 'FontSize', legend_fontsize);
                ylabel('Time (sec)');
                %title(['Time vs. planted rank ' distro{:}]);
        end
    end
end

%% Density
data=load([res_dir 'vary_dens_all.mat']);
projections = {'proje', 'nuclear', 'SVD', 'lpca', 'shay', 'LB'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_small_vary_dens_%s_%s', distro{:}, prop{:});
        e=[];
        hold on;
        for proj = projections
            e(end+1) = errorbar(data.Density, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        if prop{:} == 'rank'
            plot([data.Density(1) data.Density(end)], [defaultK defaultK], 'Color', [0.5 0.5 0.5], 'LineStyle', '--', 'LineWidth', linewidth);
        end        
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.Density);
        axis tight
        
        xlabel('Expected value');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                %title(['Estimated rank vs. density ' distro{:}]);
            case 'time'
                %l = legend(e, algo_names, 'Location', 'best', 'FontSize', legend_fontsize);
                ylabel('Time (sec)');
                %title(['Time vs. density ' distro{:}]);
        end
    end
end

%% Noise
data=load([res_dir 'vary_noise_all.mat']);
projections = {'proje', 'nuclear', 'SVD', 'lpca', 'shay', 'LB'};
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
distros = {'norm', 'unif'};
properties = {'rank', 'time'};

for prop=properties
    for distro=distros
        h(end+1)=figure;
        plotnames{end+1} = sprintf('rank_small_vary_noise_%s_%s', distro{:}, prop{:});
        e=[];
        hold on;
        for proj = projections
            e(end+1) = errorbar(data.Noise, mean(data.(proj{:}).(distro{:}).(prop{:})), ...
                std(data.(proj{:}).(distro{:}).(prop{:})), ...
                'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                'LineWidth', linewidth, 'MarkerSize', markersize);
        end
        set(gca, 'FontSize', fontsize);
        set(gca, 'XTick', data.Noise);
        axis tight
        
        xlabel('Noise level');
        switch prop{:}
            case 'rank'
                ylabel('Estimated rank');
                %title(['Estimated rank vs. noise level ' distro{:}]);
            case 'time'
                %l = legend(e, algo_names, 'Location', 'best', 'FontSize', legend_fontsize);
                ylabel('Time (sec)');
                %title(['Time vs. noise level ' distro{:}]);
        end
    end
end

%% Empty plot for the legend
projections = {'proje', 'nuclear', 'SVD', 'lpca', 'shay', 'LB', 'planted'}; % all algos
algo_names = cell(length(projections), 1);
for p = 1:length(projections)
    algo_names{p} = names.(projections{p});
end
h(end+1) = figure;
plotnames{end+1} = sprintf('rank_small_legend_plot');
e=[];
hold on
for proj = projections
    e(end+1) = errorbar([1,2], [1, 1], [0, 0], ...
                        'Color', colours.(proj{:}), 'Marker', markers.(proj{:}), ...
                        'LineWidth', linewidth, 'MarkerSize', markersize, ...
                        'LineStyle', linestyle.(proj{:}));
end
ylim([0 100]);
l = legend(e, algo_names, 'Location', 'North', ...
           'FontSize', legend_fontsize);


%% Projection and N
data=load([res_dir 'vary_projections_and_n_all.mat']);
algo_names = {'Sparse', 'Normal', 'Binary', 'Uniform'};
distros = {'unif'};
properties = {'rank', 'time'};

linestyles = struct('sparse', '-', 'normal', '-.', 'binary', '--', 'uniform', ':');

for prop=properties
    h(end+1)=figure;
    plotnames{end+1} = sprintf('rank_small_vary_projection_and_n_%s', prop{:});
    hold on;
    for proj = data.projections
        errorbar(data.N, mean(data.proje.(proj{:}).(prop{:})), ...
            std(data.proje.(proj{:}).(prop{:})), ...
            'Color', colours.proje, 'Marker', markers.proje, ...
            'LineStyle', linestyles.(proj{:}), ...
            'LineWidth', linewidth, 'MarkerSize', markersize);
    end
    set(gca, 'FontSize', fontsize);
    set(gca, 'XTick', data.N);
    axis tight
    l = legend(algo_names, 'Location', 'best', 'FontSize', legend_fontsize);
    xlabel('Rows in matrix');
    switch prop{:}
        case 'rank'
            ylabel('Estimated rank');
            %title(['Estimated rank vs. rows in matrix with different projections']);
        case 'time'
            ylabel('Time (sec)');
            %title(['Time vs. rows in matrix with different projections']);
    end
end
