%PRINT_REAL_TABLES Prints the real-world experiment tables
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

datasets={'abstracts', 'apj', 'dblp', 'dialect', 'now'};
algos = {'proje', 'lpca', 'SVD', 'truncSVD', 'asso'};

rank_datasets = {'apj', 'dblp', 'dialect', 'now'};
rank_algos = {'proje', 'lpca', 'SVD'};

resdir = '../results/real/';
errfile = '../paper/real_errors_tab.tex';
timefile = '../paper/real_times_tab.tex';
rankfile = '../paper/real_ranks_tab.tex';
ranktimefile = '../paper/real_ranktimes_tab.tex';

%% Errors
fid = fopen(errfile, 'w');

% Header, we have 5 datasets, 3 ranks for each
fprintf(fid, '\\begin{tabular}{@{}lrrrrrrrrrrrrrrr@{}}\n');
fprintf(fid, '\\toprule \n');
fprintf(fid, '\t ');
for ds=datasets, fprintf(fid, '& \\multicolumn{3}{c}{\\%s} ', ds{:}); end
fprintf(fid, '\\\\\n');
fprintf(fid, '\t \\cmidrule(r){2-4}\t \\cmidrule(lr){5-7}\t \\cmidrule(lr){8-10}\t \\cmidrule(lr){11-13}\t \\cmidrule(l){14-16}\n');
fprintf(fid, 'Method ');
for ds=datasets, 
    d = load([resdir ds{:} '_err.mat']); 
    for i=1:3, fprintf(fid, '& $k=%i$ ', d.K(i)); end
end
fprintf(fid, '\\\\\n');
fprintf(fid, '\\midrule \n'); 

% The errors
for algo=algos
    alg = algo{:};
    fprintf(fid, '\\%s ', alg);
    for ds=datasets, 
        d=load([resdir ds{:} '_err.mat']); 
        for i=1:3, 
            fprintf(fid, '& $%.3f$ ', d.(alg).err(i)/d.(alg).nnz(1)); 
        end, 
    end; 
    fprintf(fid, ' \\\\\n');
end

% Footer
fprintf(fid, '\\bottomrule \n');
fprintf(fid, '\\end{tabular} \n');

fclose(fid);

%% Time
fid = fopen(timefile, 'w');

% Header, we have 5 datasets, 3 ranks for each
fprintf(fid, '\\begin{tabular}{@{}lrrrrrrrrrrrrrrr@{}}\n');
fprintf(fid, '\\toprule \n');
fprintf(fid, '\t ');
for ds=datasets, fprintf(fid, '& \\multicolumn{3}{c}{\\%s} ', ds{:}); end
fprintf(fid, '\\\\\n');
fprintf(fid, '\t \\cmidrule(r){2-4}\t \\cmidrule(lr){5-7}\t \\cmidrule(lr){8-10}\t \\cmidrule(lr){11-13}\t \\cmidrule(l){14-16}\n');
fprintf(fid, 'Method ');
for ds=datasets, 
    d = load([resdir ds{:} '_err.mat']); 
    for i=1:3, fprintf(fid, '& $k=%i$ ', d.K(i)); end
end
fprintf(fid, '\\\\\n');
fprintf(fid, '\\midrule \n'); 

% The errors
for algo=algos
    alg = algo{:};
    fprintf(fid, '\\%s ', alg);
    for ds=datasets, 
        d=load([resdir ds{:} '_err.mat']); 
        for i=1:3, 
            fprintf(fid, '& $%i$ ', ceil(d.(alg).time(i))); 
        end, 
    end; 
    fprintf(fid, ' \\\\\n');
end

% Footer
fprintf(fid, '\\bottomrule \n');
fprintf(fid, '\\end{tabular} \n');

fclose(fid);

%% Ranks
fid = fopen(rankfile, 'w');

% Header, we have 4 datasets
fprintf(fid, '\\begin{tabular}{@{}lrrrr@{}}\n');
fprintf(fid, '\\toprule \n');
fprintf(fid, 'Method ');
for ds=rank_datasets, fprintf(fid, '& \\%s ', ds{:}); end
fprintf(fid, '\\\\\n');
fprintf(fid, '\\midrule \n'); 

% The errors
for algo=rank_algos
    alg = algo{:};
    fprintf(fid, '\\%s ', alg);
    for ds=rank_datasets, 
        d=load([resdir ds{:} '_rank.mat']); 
        fprintf(fid, '& $%i$ ', d.(alg).rank); 
    end; 
    fprintf(fid, ' \\\\\n');
end

% Footer
fprintf(fid, '\\bottomrule \n');
fprintf(fid, '\\end{tabular} \n');

fclose(fid);

%% Rank times
fid = fopen(ranktimefile, 'w');

% Header, we have 4 datasets
fprintf(fid, '\\begin{tabular}{@{}lrrrr@{}}\n');
fprintf(fid, '\\toprule \n');
fprintf(fid, 'Method ');
for ds=rank_datasets, fprintf(fid, '& \\%s ', ds{:}); end
fprintf(fid, '\\\\\n');
fprintf(fid, '\\midrule \n'); 

% The errors
for algo=rank_algos
    alg = algo{:};
    fprintf(fid, '\\%s ', alg);
    for ds=rank_datasets, 
        d=load([resdir ds{:} '_rank.mat']); 
        fprintf(fid, '& $%i$ ', ceil(d.(alg).time)); 
    end; 
    fprintf(fid, ' \\\\\n');
end

% Footer
fprintf(fid, '\\bottomrule \n');
fprintf(fid, '\\end{tabular} \n');

fclose(fid);