%RUN_REAL_RANK_DBLP Finds the rounding rank of the DBLP data
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

resdir = '../results/real/';
dataname = 'dblp';

XY = importdata('../data/real/dblp/data_sparse.txt');
B = sparse(XY(:,1), XY(:,2), 1);

B(B > 1) = 1; % Make sure B is binary

tau = 0.5;
replicates = 5;

% Projection w/ Gurobi
fprintf('**********************\n* Projection\n**********************\n');
tic
[r, X] = RoundingRankProj(B, 'threshold', tau, 'solver', 'gurobi', 'replicates', replicates);
time = toc;
proje.rank = r;
proje.X = X;
proje.time = time;
save([resdir dataname '_rank_proje'], 'proje');

% SVD
fprintf('**********************\n* SVD\n**********************\n');
tic
[r, X] = RoundingRankSVD(B, 'threshold', tau);
time = toc;
SVD.rank = r;
SVD.X = X;
SVD.time = time;
save([resdir dataname '_rank_svd'], 'SVD');


% Logistic PCA
fprintf('**********************\n* LPCA\n**********************\n');
tic
[r, X, iters] = RoundingRankLPCA(B, 'threshold', tau, 'replicates', replicates);
time = toc;
lpca.rank = r;
lpca.X = X;
lpca.time = time;
lpca.iters = iters;
save([resdir dataname '_rank_lpca'], 'lpca');

