%RUN_REAL_RANK_DIALECT Finds the rounding rank of the Dialect data
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

resdir = '../results/real/';
dataname = 'dialect';

B = importdata('../data/real/dialect/data_matlab.txt');

tau = 0.5;
replicates = 5;

% Projection w/ Gurobi
fprintf('**********************\n* Projection\n**********************\n');
tic
[r, X] = RoundingRankProj(B, 'threshold', tau, 'solver', 'gurobi', 'replicates', replicates);
time = toc;
proje.rank = r;
proje.X = X;
proje.time = time;
save([resdir dataname '_rank_proje'], 'proje');

% SVD
fprintf('**********************\n* SVD\n**********************\n');
tic
[r, X] = RoundingRankSVD(B, 'threshold', tau);
time = toc;
SVD.rank = r;
SVD.X = X;
SVD.time = time;
save([resdir dataname '_rank_svd'], 'SVD');


% Logistic PCA
fprintf('**********************\n* LPCA\n**********************\n');
tic
[r, X, iters] = RoundingRankLPCA(B, 'threshold', tau, 'replicates', replicates);
time = toc;
lpca.rank = r;
lpca.X = X;
lpca.time = time;
lpca.iters = iters;
save([resdir dataname '_rank_lpca'], 'lpca');

