function save_synth_result_plots(h, names, dir)
%SAVE_SYNTH_RESULT_PLOTS Saves the plots for synthetic experiments
%
%   SAVE_SYNTH_RESULT_PLOTS(h, names) saves the figures pointed by the
%   handles in vector h to files whose names come from the cell array
%   names. 
%
%   SAVE_SYNTH_RESULT_PLOTS(h, names, dir) saves the resulting figures to
%   directory dir instead of the default '../figs/'. 
%
%   SAVE_SYNTH_RESULT_PLOTS requires Unix environment and 'epstopdf'
%   command-line utility.
%
%   This code is free to use for scientific purposes provided that the
%   original paper is cited.
%
%   Copyright Pauli Miettinen & Stefan Neumann, 2016

if nargin < 3
    dir='../figs';
end

for i=1:length(h)
    savefig(h(i), [dir '/' names{i}]); % Save a fig version for editing
    filename = sprintf('%s/%s.eps', dir, names{i});
    print(h(i), filename, '-depsc', '-r300');
    [s, m] = unix(['epstopdf --embed --pdfsettings=prepress ' filename]);
    if s,
        warning('Failed to run epstopdf for file %s:\n%s', filename, m);
    end
end
